Skip to contents

A dataset containing two illustrative participants' 21-item MCQ (Kirby & Marakovic, 1996) responses: subject 1 responds like the median subject in Kirby & Marakovic (1996) (switching between the eighth and ninth ladder items, overall k of about 0.007) and subject 2 always chooses the larger delayed reward. These responses are constructed for illustration only, not drawn from an empirical sample.

Usage

mcq21

Format

Long-form data.frame with columns: subjectid, questionid, response.

Constructed in data-raw/mcq21_data.R.