Checks a data set against the two Johnson and Bickel (2008) criteria for unsystematic delay-discounting data:
Criterion 1: Any subsequent value of
yexceeds the previous value by more than a specified proportion of the larger later reward (ll).Criterion 2: The last value of
yis not at least a specified proportion ofllless than the first value ofy(a decline of exactlyc2 * llpasses).
Arguments
- dat
A data frame containing the delay-discounting data. It must have at least two columns:
id: A unique identifier for the data set.y: The indifference points to be analyzed.x(optional): Delay values; when present, each subject's points are ordered by delay first.
Missing
yorxvalues and duplicate delays within a subject are errors.- ll
A numeric value representing the larger later reward, in the same units as
y. Default is 1 (indifference points expressed as a proportion of the larger later reward). Both thresholds are applied on theyscale (c1 * llandc2 * ll), so amount-scale data (e.g.yin dollars) needllset to the larger later amount.- c1
A numeric value for the threshold proportion for Criterion 1. Default is 0.2.
- c2
A numeric value for the threshold proportion for Criterion 2. Default is 0.1.
Value
A tibble with the following columns:
id: The unique identifier for the data set.c1_pass: Logical value indicating whether Criterion 1 was passed.c2_pass: Logical value indicating whether Criterion 2 was passed.