A dataset containing a set of fake delay discounting responses
A data frame with 600 rows and 3 columns:
- id
Subject identifier.
- x
Delay until the larger, later reward (in days).
- y
Indifference point, expressed as a proportion of the larger, later
reward (these synthetic values are near, but not strictly within, the unit
interval).